/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { OnChanges, OnDestroy, SimpleChanges } from '@angular/core';
import { ListBoxComponent } from './listbox.component';
import * as i0 from "@angular/core";
/**
 * Represents the data-binding directive for the Kendo UI ListBox for Angular.
 * Manages the functionality of the ListBox tools out of the box and modifies the provided data accordingly.
 *
 * @example
 * ```typescript
 * @Component({
 *   selector: 'my-app',
 *   template: `
 *     <kendo-listbox
 *       kendoListBoxDataBinding
 *       [connectedWith]="targetListBox"
 *       [data]="sourceData">
 *     </kendo-listbox>
 *   `
 * })
 * export class AppComponent { }
 * ```
 *
 * @remarks
 * Applied to: {@link ListBoxComponent}.
 */
export declare class DataBindingDirective implements OnChanges, OnDestroy {
    private listbox;
    /**
     * Specifies the `ListBoxComponent` instance with which the current ListBox connects.
     * When you link two listboxes through this input, you can transfer items between them.
     */
    connectedWith: ListBoxComponent;
    private actionClickSub;
    private selectedBoxSub;
    private connectedWithSub;
    private selectedBox;
    constructor(listbox: ListBoxComponent);
    /**
     * @hidden
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * @hidden
     */
    ngOnDestroy(): void;
    private moveVertically;
    private removeItem;
    private transferItem;
    private transferAll;
    static ɵfac: i0.ɵɵFactoryDeclaration<DataBindingDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<DataBindingDirective, "[kendoListBoxDataBinding]", never, { "connectedWith": { "alias": "connectedWith"; "required": false; }; }, {}, never, never, true, never>;
}
