/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Allows you to customize the rendering of each item in the Kendo UI ListBox for Angular.
 *
 * Place an `<ng-template>` with the `kendoListBoxItemTemplate` directive inside your `<kendo-listbox>` component.
 * The template context exposes the current data item as `let-dataItem`.
 *
 * @example
 * ```typescript
 * @Component({
 *   selector: 'my-app',
 *   template: `
 *     <kendo-listbox [data]="listBoxItems">
 *       <ng-template kendoListBoxItemTemplate let-dataItem>
 *         <span>{{ dataItem }} item</span>
 *       </ng-template>
 *     </kendo-listbox>
 *   `
 * })
 * export class AppComponent { }
 * ```
 */
export declare class ItemTemplateDirective {
    templateRef: TemplateRef<any>;
    constructor(templateRef: TemplateRef<any>);
    static ɵfac: i0.ɵɵFactoryDeclaration<ItemTemplateDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ItemTemplateDirective, "[kendoListBoxItemTemplate]", never, {}, {}, never, never, true, never>;
}
