/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { SVGIcon } from "@progress/kendo-svg-icons";
/**
 * Defines the possible toolbar buttons that the ListBox can display.
 */
export type ActionName = 'moveUp' | 'moveDown' | 'transferTo' | 'transferFrom' | 'transferAllTo' | 'transferAllFrom' | 'remove';
/**
 * Defines the possible values for customizing the toolbar position of the ListBox component.
 */
export type ListBoxToolbarPosition = 'left' | 'right' | 'top' | 'bottom';
/**
 * Defines the possible tool and position settings that the ListBox can accept for its built-in toolbar.
 */
export interface Toolbar {
    /**
     * Specifies the set of tools to display in the toolbar.
     * When you omit this setting, all tools are included.
     */
    tools?: ActionName[];
    /**
     * Specifies the position of the toolbar.
     */
    position?: ListBoxToolbarPosition;
}
/**
 * Defines the possible values that the ListBox can accept for its built-in toolbar.
 *
 * - Use `false` to hide the toolbar.
 * - Omit the setting or use `true` to show the default settings, which are the full set of possible tools and position `"right"`.
 * - Use a config object of type [`Toolbar`]({% slug api_listbox_toolbar %}) to specify tools or position. When you specify only [`tools`]({% slug api_listbox_toolbar %}#toc-tools) or [`position`]({% slug api_listbox_toolbar %}#toc-position), the other property will use its default value.
 *
 */
export type ListBoxToolbarConfig = boolean | Toolbar;
/**
 * @hidden
 */
export interface Tool {
    name: ActionName;
    label: string;
    icon: string;
    svgIcon: SVGIcon;
}
